Gray

Trait Gray 

pub trait Gray: Mix + Sized {
    const BLACK: Self;
    const WHITE: Self;

    // Provided method
    fn gray(lightness: f32) -> Self { ... }
}
Trait for returning a grayscale color of a provided lightness.

Required Associated Constants

const BLACK: Self

A pure black color.

const WHITE: Self

A pure white color.

Provided Methods

fn gray(lightness: f32) -> Self

Returns a grey color with the provided lightness from (0.0 - 1.0). 0 is black, 1 is white.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Gray for Hsla

Source

const BLACK: Self

Source

const WHITE: Self

Source

impl Gray for Hsva

Source

const BLACK: Self

Source

const WHITE: Self

Source

impl Gray for Hwba

Source

const BLACK: Self

Source

const WHITE: Self

Source

impl Gray for Laba

Source

const BLACK: Self

Source

const WHITE: Self

Source

impl Gray for Lcha

Source

const BLACK: Self

Source

const WHITE: Self

Source

impl Gray for LinearRgba

Source

const BLACK: Self = Self::BLACK

Source

const WHITE: Self = Self::WHITE

Source

impl Gray for Oklaba

Source

const BLACK: Self

Source

const WHITE: Self

Source

impl Gray for Oklcha

Source

const BLACK: Self

Source

const WHITE: Self

Source

impl Gray for Srgba

Source

const BLACK: Self = Self::BLACK

Source

const WHITE: Self = Self::WHITE

Source

impl Gray for Xyza

Source

const BLACK: Self

Source

const WHITE: Self