pub trait ColorRange<T: Mix> {
// Required method
fn at(&self, factor: f32) -> T;
}Expand description
Represents a range of colors that can be linearly interpolated, defined by a start and
end point which must be in the same color space. It works for any color type that
implements Mix.
This is useful for defining gradients or animated color transitions.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".